@@ -5,8 +5,8 @@
 
 ;; Author: Shen, Jen-Chieh <jcs090218@gmail.com>
 ;; URL: https://github.com/emacs-vs/goto-char-preview
-;; Package-Version: 20260101.549
-;; Package-Revision: b78fa6419466
+;; Package-Version: 20260204.956
+;; Package-Revision: d81c7186dc3c
 ;; Package-Requires: ((emacs "24.3"))
 ;; Keywords: convenience character navigation
 
@@ -32,6 +32,8 @@
 
 ;;; Code:
 
+(require 'isearch)
+
 (defgroup goto-char-preview nil
   "Preview char when executing `goto-char` command."
   :prefix "goto-char-preview-"
@@ -57,7 +59,7 @@
 (defface goto-char-preview-hl
   '((t :inherit highlight :extend t))
   "Face to use for highlighting when change preview char."
-  :group 'goto-line-preview)
+  :group 'goto-char-preview)
 
 (defvar goto-char-preview--prev-window nil
   "Record down the previous window before we do preview command.")
@@ -68,6 +70,9 @@
 (defvar goto-char-preview--relative-p nil
   "Flag to see if this command relative.")
 
+(defvar goto-char-preview--executing-p nil
+  "Set to t when the command is getting executed.")
+
 (defun goto-char-preview--highlight ()
   "Keep highlight for a fixed time."
   (when goto-char-preview-hl-duration
@@ -86,12 +91,17 @@ CHAR-POS : Target character position to navigate to."
     (when (< (point-max) char-pos)
       (setq char-pos (point-max)))
     (forward-char (1- char-pos))
+    (ignore-errors
+      (let ((search-invisible 'open))
+        (isearch-range-invisible (1- char-pos)
+                                 char-pos)))
     (goto-char-preview--highlight)))
 
 (defun goto-char-preview--do-preview ()
   "Do the goto char preview action."
-  (save-selected-window
-    (when goto-char-preview--prev-window
+  (when (and goto-char-preview--executing-p
+             goto-char-preview--prev-window)
+    (save-selected-window
       (let ((char-pos-str (thing-at-point 'line)))
         (select-window goto-char-preview--prev-window)
         (if char-pos-str
@@ -106,7 +116,8 @@ CHAR-POS : Target character position to navigate to."
 (defun goto-char-preview ()
   "Preview goto char."
   (interactive)
-  (let ((goto-char-preview--prev-window (selected-window))
+  (let ((goto-char-preview--executing-p t)
+        (goto-char-preview--prev-window (selected-window))
         (window-point (window-point))
         (goto-char-preview--prev-char-pos (point))
         jumped)
@@ -134,8 +145,7 @@ CHAR-POS : Target character position to navigate to."
 
 (defun goto-char-preview--minibuffer-setup ()
   "Locally set up preview hooks for this minibuffer command."
-  (when (memq this-command '(goto-char-preview goto-char-preview-relative))
-    (add-hook 'post-command-hook #'goto-char-preview--do-preview nil t)))
+  (add-hook 'post-command-hook #'goto-char-preview--do-preview nil t))
 
 (add-hook 'minibuffer-setup-hook 'goto-char-preview--minibuffer-setup)
 
